package com.zhyc.module.biosafety.service;

import java.util.List;
import com.zhyc.module.biosafety.domain.Health;

/**
 * 保健Service接口
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
public interface IHealthService 
{
    /**
     * 查询保健
     * 
     * @param id 保健主键
     * @return 保健
     */
    public Health selectHealthById(Long id);

    /**
     * 查询保健列表
     * 
     * @param health 保健
     * @return 保健集合
     */
    public List<Health> selectHealthList(Health health);

    /**
     * 新增保健
     * 
     * @param health 保健
     * @return 结果
     */
    public int insertHealth(Health health);

    /**
     * 修改保健
     * 
     * @param health 保健
     * @return 结果
     */
    public int updateHealth(Health health);

    /**
     * 批量删除保健
     * 
     * @param ids 需要删除的保健主键集合
     * @return 结果
     */
    public int deleteHealthByIds(Long[] ids);

    /**
     * 删除保健信息
     * 
     * @param id 保健主键
     * @return 结果
     */
    public int deleteHealthById(Long id);
}
